@@ -1,4 +1,4 @@
-/*$Id: formail.h,v 1.11 1994/05/26 14:12:44 berg Exp $*/
+/*$Id: formail.h,v 1.13 1994/09/29 18:43:44 berg Exp $*/
 
 #define Bsize		128
 
@@ -13,11 +13,11 @@
 #define PWRO		poutfd[1]
 #define FLD_HEADSIZ	((size_t)offsetof(struct field,fld_text[0]))
 
-struct saved{const char*const headr;const int lenr;int rexl;char*rexp;};
+struct saved {const char*const headr;const int lenr;int rexl;char*rexp;};
 
 extern const char binsh[],sfolder[],couldntw[];
 extern char ffileno[];
-extern int errout,oldstdout,quiet,buflast,lenfileno;
+extern int errout,oldstdout,quiet,zap,buflast,lenfileno;
 extern long initfileno;
 extern pid_t child;
 extern unsigned long rhash;
